==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/FhirServiceExportConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.FhirServiceExportConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Export operation configuration information
 * @property storageAccountName The name of the default export storage account.
 */
public data class FhirServiceExportConfigurationArgs(
    public val storageAccountName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.FhirServiceExportConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceExportConfigurationArgs =
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceExportConfigurationArgs.builder()
            .storageAccountName(storageAccountName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FhirServiceExportConfigurationArgs].
 */
@PulumiTagMarker
public class FhirServiceExportConfigurationArgsBuilder internal constructor() {
    private var storageAccountName: Output<String>? = null

    /**
     * @param value The name of the default export storage account.
     */
    @JvmName("lyltypselgmsmdcr")
    public suspend fun storageAccountName(`value`: Output<String>) {
        this.storageAccountName = value
    }

    /**
     * @param value The name of the default export storage account.
     */
    @JvmName("oailbxrgkscltokm")
    public suspend fun storageAccountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountName = mapped
    }

    internal fun build(): FhirServiceExportConfigurationArgs = FhirServiceExportConfigurationArgs(
        storageAccountName = storageAccountName,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/FhirServiceExportConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.FhirServiceExportConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Export operation configuration information
 * @property storageAccountName The name of the default export storage account.
 */
public data class FhirServiceExportConfigurationArgs(
    public val storageAccountName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.FhirServiceExportConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceExportConfigurationArgs =
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceExportConfigurationArgs.builder()
            .storageAccountName(storageAccountName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FhirServiceExportConfigurationArgs].
 */
@PulumiTagMarker
public class FhirServiceExportConfigurationArgsBuilder internal constructor() {
    private var storageAccountName: Output<String>? = null

    /**
     * @param value The name of the default export storage account.
     */
    @JvmName("dmhvvvnhdmrhvvdt")
    public suspend fun storageAccountName(`value`: Output<String>) {
        this.storageAccountName = value
    }

    /**
     * @param value The name of the default export storage account.
     */
    @JvmName("mfnirvguilocrwjw")
    public suspend fun storageAccountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountName = mapped
    }

    internal fun build(): FhirServiceExportConfigurationArgs = FhirServiceExportConfigurationArgs(
        storageAccountName = storageAccountName,
    )
}
